@@ -190,7 +190,8 @@ class DotPack:
 
         if self._is_local():
             self._img.putpixel((x, y), color)
-            self.show_here(self._img)
+            if show:
+                self.show_here(self._img)
         else:
             # to bag
             r, g, b = color
@@ -336,6 +337,13 @@ class DotPack:
             # to bag
             self._show_image(img, PILimage=PILimage)
 
+    def clear(self):
+        self._img = Image.new(mode="RGB", size=(self.size, self.size))
+        if self._is_local():
+            return self.show()
+        else:
+            self._execute(self._ledpanel.clear())
+
     def set_brightness(self, brightness):
         self._execute(self._ledpanel.set_brightness(brightness))
 
@@ -353,9 +361,6 @@ class DotPack:
         """关闭屏幕 (仅在硬件上运行, 不支持模拟器)"""
         self._execute(self._ledpanel.off())
 
-    def clear(self):
-        self._execute(self._ledpanel.clear())
-
     def close(self):
         self.disconnect()
 
